<?php

namespace Figmax\Slider\Providers;

use Illuminate\Support\ServiceProvider;

class SliderServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'slider');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'slider');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('figmax.slider', function ($app) {
            return $this->app->make('Figmax\Slider\Slider');
        });

                // Bind Slider to repository
        $this->app->bind(
            'Figmax\Slider\Interfaces\SliderRepositoryInterface',
            \Figmax\Slider\Repositories\Eloquent\SliderRepository::class
        );

        $this->app->register(\Figmax\Slider\Providers\AuthServiceProvider::class);
                $this->app->register(\Figmax\Slider\Providers\EventServiceProvider::class);
        
        $this->app->register(\Figmax\Slider\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['figmax.slider'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('figmax/slider.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/slider')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/slider')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
